A Python micro framework for REST APIs and single-page-applications.  See `the
docs`_ for more.


.. image:: https://api.travis-ci.org/btubbs/spa.svg?branch=master
  :target: https://travis-ci.org/btubbs/spa

.. _the docs: http://spa.readthedocs.org/en/latest/
